<?php

namespace Litecms\Instructor\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Instructor\Models\Instructor;

class InstructorPolicy
{

    /**
     * Determine if the given user can view the instructor.
     *
     * @param UserPolicyInterface $authUser
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Instructor $instructor)
    {
        if ($authUser->canDo('instructor.instructor.view') && $authUser->isAdmin()) {
            return true;
        }

        return $instructor->user_id == user_id() && $instructor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a instructor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('instructor.instructor.create');
    }

    /**
     * Determine if the given user can update the given instructor.
     *
     * @param UserPolicyInterface $authUser
     * @param Instructor $instructor
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Instructor $instructor)
    {
        if ($authUser->canDo('instructor.instructor.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $instructor->user_id == user_id() && $instructor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given instructor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Instructor $instructor)
    {
        return $instructor->user_id == user_id() && $instructor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given instructor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Instructor $instructor)
    {
        if ($authUser->canDo('instructor.instructor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given instructor.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Instructor $instructor)
    {
        if ($authUser->canDo('instructor.instructor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
